#pragma once

#define STREAMING_TYPE_ATCP10		1
#define STREAMING_TYPE_ATCP20		2
#define STREAMING_TYPE_NVR			3

#define MOBILE_CONTACT_TYPE_UNICAST_PREVIEW				2

typedef struct structural_MEDIA_CONNECTION_CONFIG
{
	int				ContactType;
	int				ChannelNumber;
	char			UniCastIP[16];
	char			MultiCastIP[16];
	char			PlayFileName[256];
	char			UserID[64];
	char			Password[64];
	unsigned long	RegisterPort;
	unsigned long	StreamingPort;
	unsigned long	ControlPort;
	unsigned long	MultiCastPort;
	unsigned long	SearchPortC2S;
	unsigned long	SearchPortS2C;
	unsigned long	HTTPPort;
	unsigned long	RTSPPort;
	unsigned long	VideoRTPOverMCastPort;
	unsigned long	AudioRTPOverMCastPort;
	int				ConnectTimeOut;
}MEDIA_CONNECTION_CONFIG;

typedef struct structural_STREAMING_ENGINE_CONFIG
{
	char      szUserID[16];                       // Streaming engine login ID
	char      szUserPwd[16];                    // Streaming engine login Password
	char      szServerIP[16];                     // Streaming engine IP address
	DWORD dwStreamingPort;                  // Audio/Video port number for streaming engine
	DWORD dwControlPort;                      // Control port number for streaming engine
}STREAMING_ENGINE_CONFIG;

typedef struct structural_MEDIA_RENDER_INFO
{
	int	  DrawerInterface;		///< Reserve, in the future this parameter meaning DGDI or DDRAW
	HWND  hWnd;
	RECT  rect;
} MEDIA_RENDER_INFO;

typedef struct structural_MEDIA_PTZ_PROTOCOL
{
	int	  nSourceType;
	char  szVender[32];
	char  szProtocol[32];
	char  szProtocolFilename[512];
	DWORD dwAddressID;
} MEDIA_PTZ_PROTOCOL;

typedef void ( CALLBACK *NETWORK_LOSS_CALLBACK		)( DWORD UserParam );
typedef void ( CALLBACK *AFTER_RENDER_CALLBACK		)( DWORD UserParam );
typedef void ( CALLBACK *MOTION_DETECTION_CALLBACK	)( DWORD UserParam, bool Motion1, bool Motion2, bool Motion3, bool Motion4 );
typedef void ( CALLBACK *DI_CALLBACK				)( DWORD UserParam, bool DI1, bool DI2 );

extern "C" __declspec(dllexport) HANDLE M_KOpenInterface();
extern "C" __declspec(dllexport) void M_KCloseInterface( HANDLE h );
extern "C" __declspec(dllexport) void M_KSetStreamingType( HANDLE h, int nStreamingType );
extern "C" __declspec(dllexport) bool M_KSetMediaConfig( HANDLE h, MEDIA_CONNECTION_CONFIG* MediaConfig, STREAMING_ENGINE_CONFIG* StreamingEngineConfig = NULL );
extern "C" __declspec(dllexport) void M_KSetRenderInfo( HANDLE h, MEDIA_RENDER_INFO * pMRI );
extern "C" __declspec(dllexport) bool M_KConnect( HANDLE h );
extern "C" __declspec(dllexport) void M_KDisconnect( HANDLE h );

// Media
extern "C" __declspec(dllexport) void M_KSetMute( HANDLE h, bool bMute );

//Quad
extern "C" __declspec(dllexport) bool M_KQuadSetDisplayMode( HANDLE h, int nMode );

//Callback
extern "C" __declspec(dllexport) void M_KSetNetworkLossCallback( HANDLE h, DWORD dwUserParam, NETWORK_LOSS_CALLBACK fnCallback );
extern "C" __declspec(dllexport) void M_KSetAfterRenderCallback( HANDLE h, DWORD dwUserParam, AFTER_RENDER_CALLBACK fnCallback );
extern "C" __declspec(dllexport) void M_KSetMotionDetectionCallback( HANDLE h, DWORD dwUserParam, MOTION_DETECTION_CALLBACK fnCallback, bool bQuad = false );
extern "C" __declspec(dllexport) void M_KSetDICallback( HANDLE h, DWORD dwUserParam, DI_CALLBACK fnCallback );

// IP Cam / Video Server RS232 Setting
#define NET_N81			0x00		// N,    8, 1
#define NET_O81			0x08		// Odd,  8, 1
#define NET_E81			0x18		// Even, 8, 1
// IP Cam / Video Server RS232 BaudRate Setting
#define NET_1200BPS		0X00
#define NET_2400BPS		0X01
#define NET_4800BPS		0X02
#define NET_9600BPS		0X03
#define NET_19200BPS	0X04
#define NET_38400BPS	0X05
#define NET_57600BPS	0X06
#define NET_115200BPS	0X07
#define NET_230400BPS	0X08
// IP Cam / Video Server RS232 
extern "C" __declspec(dllexport) bool M_KSendRS232Setting( HANDLE h, BYTE c81, BYTE dwBaudRate );

// PTZ
extern "C" __declspec(dllexport) bool M_KEnablePTZProtocol( HANDLE h, bool bEnable, MEDIA_PTZ_PROTOCOL * pMPP );
extern "C" __declspec(dllexport) bool M_KPTZ_UP( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_DOWN( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_LEFT( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_RIGHT( HANDLE h, int nSpeed );
#define PTZ_STOP_MOVE_ALL	0
#define PTZ_STOP_MOVE_UP	1
#define PTZ_STOP_MOVE_DOWN	2
#define PTZ_STOP_MOVE_LEFT	3
#define PTZ_STOP_MOVE_RIGHT	4
extern "C" __declspec(dllexport) bool M_KPTZ_STOP( HANDLE h, int nDirect );
extern "C" __declspec(dllexport) bool M_KPTZ_GOTO_PRESET( HANDLE h, int nPersetPos );
extern "C" __declspec(dllexport) bool M_KPTZ_SET_PRESET( HANDLE h, int nPersetPos );
extern "C" __declspec(dllexport) bool M_KPTZ_ZOOM_IN( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_ZOOM_OUT( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_ZOOM_IN_STOP( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_ZOOM_OUT_STOP( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_UP_RIGHT( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_DOWN_RIGHT( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_UP_LEFT( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_DOWN_LEFT( HANDLE h, int nSpeed );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_ON( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_OFF( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_UP( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_DOWN( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_LEFT( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_RIGHTT( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_ENTER( HANDLE h );
extern "C" __declspec(dllexport) bool M_KPTZ_OSD_LEAVE( HANDLE h );
extern "C" __declspec(dllexport) bool M_KGetAudioToken( HANDLE h, char* pholder );
extern "C" __declspec(dllexport) void M_KFreeAudioToken( HANDLE h );
extern "C" __declspec(dllexport) bool M_KStartAudioTransfer( HANDLE h );
extern "C" __declspec(dllexport) void M_KStopAudioTransfer( HANDLE h );

#define DO_1	0x01
#define DO_2	0x02
#define DO_BOTH 0x03
#define DO_STOP 0x00
extern "C" __declspec(dllexport) void M_KSendDO( HANDLE h, BYTE bDOData );
extern "C" __declspec(dllexport) void M_KSetVariableFPS( HANDLE h, DWORD dwVariableFPS );